@@ -10,7 +10,7 @@ use WebService::SSLLabs::Host();
 use WebService::SSLLabs::Endpoint();
 use WebService::SSLLabs::StatusCodes();
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub _MINIMUM_ETA_TIME { return 10; }
 
@@ -24,11 +24,31 @@ sub new {
     return $self;
 }
 
+sub _parse_success {
+    my ( $self, $response ) = @_;
+    $self->{max_assessments} =
+      $response->headers()->header('X-Max-Assessments');
+    $self->{current_assessments} =
+      $response->headers()->header('X-Current-Assessments');
+    return;
+}
+
+sub max_assessments {
+    my ($self) = @_;
+    return $self->{max_assessments};
+}
+
+sub current_assessments {
+    my ($self) = @_;
+    return $self->{current_assessments};
+}
+
 sub info {
     my ($self)   = @_;
     my $url      = $self->{url} . 'info';
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
+        $self->_parse_success($response);
         return WebService::SSLLabs::Info->new(
             JSON::decode_json( $response->decoded_content() ) );
     }
@@ -62,6 +82,7 @@ sub analyze {
     );
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
+        $self->_parse_success($response);
         my $host = WebService::SSLLabs::Host->new(
             JSON::decode_json( $response->decoded_content() ) );
         $self->{_previous_host} = $host;
@@ -118,6 +139,7 @@ sub get_endpoint_data {
     );
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
+        $self->_parse_success($response);
         return WebService::SSLLabs::Endpoint->new(
             JSON::decode_json( $response->decoded_content() ) );
     }
@@ -131,6 +153,7 @@ sub get_status_codes {
     my $url      = $self->{url} . 'getStatusCodes';
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
+        $self->_parse_success($response);
         return WebService::SSLLabs::StatusCodes->new(
             JSON::decode_json( $response->decoded_content() ) );
     }
@@ -148,7 +171,7 @@ WebService::SSLLabs - Analyze the configuration of any SSL web server on the pub
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =head1 SYNOPSIS
 
@@ -236,6 +259,14 @@ Parameters:
 
 This call will return one L<StatusCodes|WebService::SSLLabs::StatusCodes> instance.
 
+=head2 max_assessments
+
+This call will return the maximum number of concurrent assessments the client is allowed to initiate.  This information is only available after a L<analyze|WebService::SSLLabs/"analyze">, L<analyze|WebService::SSLLabs/"get_endpoint_data">, L<analyze|WebService::SSLLabs/"info"> or L<analyze|WebService::SSLLabs/"get_status_codes"> call has been made.  It is retrieved from the X-Max-Assessments header from a successful API call.
+
+=head2 current_assessments
+
+This call will return the number of ongoing assessments submitted by this client.  This information is only available after a L<analyze|WebService::SSLLabs/"analyze">, L<analyze|WebService::SSLLabs/"get_endpoint_data">, L<analyze|WebService::SSLLabs/"info"> or L<analyze|WebService::SSLLabs/"get_status_codes"> call has been made.  It is retrieved from the X-Current-Assessments header in a successful API call.
+
 =head1 DIAGNOSTICS
 
 =over
