@@ -9,7 +9,7 @@ use WebService::SSLLabs::Protocol();
 use WebService::SSLLabs::Chain();
 use WebService::SSLLabs::Key();
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -161,6 +161,11 @@ sub supports_rc4 {
     return $self->{supportsRc4} ? 1 : 0;
 }
 
+sub rc4_only {
+    my ($self) = @_;
+    return $self->{rc4Only} ? 1 : 0;
+}
+
 sub forward_secrecy {
     my ($self) = @_;
     return $self->{forwardSecrecy};
@@ -250,7 +255,7 @@ WebService::SSLLabs::EndpointDetails - EndpointDetails object
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =head1 SUBROUTINES/METHODS
 
@@ -412,6 +417,10 @@ available on a server that responded with a redirection to some other hostname.
 
 true if the server supports at least one RC4 suite.
 
+=head2 rc4_only
+
+true if only RC4 suites are supported.
+
 =head2 forward_secrecy
 
 indicates support for Forward Secrecy
