@@ -3,7 +3,7 @@ package WebService::SSLLabs::Info;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -37,6 +37,11 @@ sub criteria_version {
     return $self->{criteriaVersion};
 }
 
+sub new_assessment_cool_off {
+    my ($self) = @_;
+    return $self->{newAssessmentCoolOff};
+}
+
 1;
 __END__
 
@@ -46,7 +51,7 @@ WebService::SSLLabs::Info - Info object
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =head1 SUBROUTINES/METHODS
 
